CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Recommended modules
 * Installation
 * Configuration
 * Additional features
 * Making it all work
 * Content blocking
 * Integration with other modules
 * Not supported or tested
 * Troubleshooting
 * Maintainers


INTRODUCTION
------------

Extensive CookiePro integration with additional features and supporting module
[Consent Support](https://www.drupal.org/project/consent_support) for
content blocking, covering common embedded iframe and script use cases.

This module supports both [CookiePro](https://www.cookiepro.com) as the
'unbranded' [OneTrust](https://www.onetrust.com/) version of the script.


REQUIREMENTS
------------

This module requires no modules outside of Drupal core to add CookiePro.  
However, if Google Tag Manager (GTM) approach (see section 'Making it all work')
you will need to add GTM to your website. We recommend using the
[GoogleTagManager](https://www.drupal.org/project/google_tag) module.


RECOMMENDED MODULES
-------------------

 * [GoogleTagManager](https://www.drupal.org/project/google_tag): Integrate with
   Google Tag Manager (GTM).
 * [Token Filter](https://www.drupal.org/project/token_filter): Allows using
   tokens provided by this module (cookie list, settings link and button) in
   text editors.


INSTALLATION
------------

 * Install as you would normally install a contributed Drupal module. Visit
   [Installing Modules](https://www.drupal.org/node/1897420) for further
   information.


CONFIGURATION
-------------

 * Make sure you have a CookiePro account, and therein a website setup with at
   least its test script published. See [CookiePro Community](https://community.cookiepro.com) if you
   need help with this.
 * Install this module, go to the module configuration page. In the tab 'Basic',
   add your script ID and check the other parameters.
   * The script ID is the value of the 'data-domain-script' attribute in the
     CookiePro script snippet, which is also the hash the URL of the website
      detail page the [CookiePro app](https://app.cookiepro.com).
   * Review the other option on this tab, as they correspond with options that
     are included in the snippet generated by CookiePro.

Configurable parameters:

 * __Basic__: These options recreate the snippet as provided by CookiePro and allow
   each aspect of it to be managed in Drupal configuration.

   * __Script domain__: CookiePro and OneTrust consent apps share the same
      scripts, but their (CDN) domain differs.

   * __Script ID__: The ID of your website/script in CookiePro.

   * __Cookie Category IDs__: The cookie category IDs of the cookie categories as
      defined in CookiePro.
      More info on [Finding the Cookie Group IDs](https://community.cookiepro.com/s/article/UUID-8102e851-d860-d465-d8d6-b1d636d68eb9?topicId=0TO1Q000000ssbjWAA)

   * __Enable Testing CDN__: Load scripts from the testing CDN, which allows for
      testing on different domains and faster propagation of published changes.
      More info on [Implementing Cookie Consent Scripts](https://community.cookiepro.com/s/article/UUID-7478d3b4-18eb-3ac0-a6fd-fb7ebff9f8dc?topicId=0TO1Q000000srd9WAA)

   * __Enable Auto-Blocking™__: Enable the Auto-Blocking™ feature. This only works if
      your CookiePro subscription supports this and Auto-Blocking™ is included in
      the published script.
      More info on [OneTrust Cookie Auto-Blocking™](https://community.cookiepro.com/s/article/UUID-c5122557-2070-65cb-2612-f2752c0cc4aa?topicId=0TO1Q000000srd8WAA)

   * __Enable 'Determine the language from HTML page'__: This only works if
     'Enable Language Detection on Scripts' is enabled on script (on publish).

 * Advanced: These options help to integrate CookiePro with Drupal.

   * __IPv4 addresses or ranges that must bypass CookiePro__: Don't include the
     CookiePro script in responses to all request from the listed IP (ranges).
     The responses won't be cached in Drupal.
     This feature is intended for debugging or inspection purposes, but the
     CookiePro scanner IP range is included by default.

     We have not received confirmation if the scanner is able to bypass the
     script (or accept all options) and be able to see the website with all
     third-party additions loaded.
 
     Also, when the supporting module [Consent Support](https://www.drupal.org/project/consent_support)
     is active, this option will guarantee that no content blocking is performed
     and the scanner will see the website in its full glory.
     More info about their IPs on [About CookiePro Hosting Options, Locations, and Backup](https://community.cookiepro.com/s/article/hosting).

     * __Excluded paths__: Don't include the CookiePro script for given paths.
       This includes common non-admin pages/paths on which CookiePro is not
       desired. Admin paths are excluded by default.

     * __Enable limiting by path__: Allows to include CookiePro only on the paths
       listed in 'Limit to paths'.

     * __Limit to paths__: Only include CookiePro on the listed paths. Requires
       'Enable limiting by path' to be checked.
       This is also intended as a debugging feature.

 * __Support Google Consent Mode__: allows to deny storages by default.
   Includes a snippet to the page, similar as explained on
   [Using Google Consent Mode to Adjust Tag Behavior Based on Consent](https://community.cookiepro.com/s/article/UUID-d81787f6-685c-2262-36c3-5f1f3369e2a7)

   * Storage types: select the storage types to deny by default.

 * __Pause Mode__: Similar to Drupal maintenance mode, this is a state-based
   toggle. When enabled, all module functionality (render-wise) will be
   prevented.
   This is very useful when introducing CookiePro on an existing site, without
   having the effects immediately visible to the end user.


ADDITIONAL FEATURES
-------------------

 * Module status indication on state report page (testing CDN in use, scripts
   not found,...).
 * CookiePro HTML snippets as templates:
   * Cookie list.
   * Cookie settings link and button (Do Not Sell), with translatable text.
 * Blocks for the snippets above.
 * Tokens for the snippets above.
 * Settings link and button as menu items. They are added to the User menu,
   disabled.
 * Status details on status report page. Checks availability of the configured
   scripts (incl. Auto-Blocking™ if enabled), warns if testing CDN is enabled.
 * Multi-domain support using URL language detection with domains, with all 
   module features scoped per domain (except for the IP bypass).


MAKING IT ALL WORK
------------------

CookiePro offers 2 solutions to implement actual blocking of assets that need
consent, or loading of assets when consent is given:

    1. The Google Tag Manager (GTM), or alternative, solution.
       This approach is always required when GTM is used to add (third party)
       scripts that set cookies, gather user data, ... that need consent.

    2. Auto-Blocking™.
       While Auto-Blocking™ Solution might help handling other third party scripts
       added by (contrib) modules, but it cannot handle:

More info on how to implement the GTM or the limitations of Auto-Blocking™:

 * [Cookie Consent Integration with Google Tag Manager](https://community.cookiepro.com/s/article/UUID-301b21c8-a73a-05e8-175a-36c9036728dc)
 * [OneTrust Cookie Auto-Blocking™](https://community.cookiepro.com/s/article/UUID-c5122557-2070-65cb-2612-f2752c0cc4aa?topicId=0TO1Q000000srd8WAA)

A few more notes about the GTM solution:

 * When a CookiePro bypass has occurred (see section 'CONFIGURATION',
   'Configurable parameters > Advanced > IPv4 addresses or ranges that must
   bypass CookiePro'), the 'OneTrustGroupsUpdated' event is triggered with value
   'bypass', allowing to respond differently to such cases in GTM.


    window.dataLayer.push({
      event: 'OneTrustGroupsUpdated',
      OnetrustActiveGroups: 'bypass'
    });

  This allows triggers, in GTM, to also match against 'bypass' and fire as if
  consent was given. To use this feature, all trigger regular expressions that
  match cookie categories need to be altered as shown below.
  For example, from

    ,C0002,

  to

    ,C0002,|bypass


CONTENT BLOCKING
----------------

None of the aforementioned solutions can, or partially handle by default:

    1. Scripts added by (contrib) modules.
    2. Iframes.
    3. Inline scripts that are not explicitely picked up by a scan and included
       in the published script.

While Auto-Blocking™ can handle, for example, Twitter embeds, it will just block
the script part from being executed.

CookiePro does offer solutions to block [iframes](https://community.cookiepro.com/s/article/UUID-3dc06342-ff6b-3578-5024-6d7c05d03283?topicId=0TO1Q000000ssbQWAQ)
and [scripts](https://community.cookiepro.com/s/article/UUID-730ad441-6c4d-7877-7f85-36f1e801e8ca?topicId=0TO1Q000000ssKJWAY)
in content, which require manipulations of the iframe and script elements.

The [Consent Support](https://www.drupal.org/project/consent_support) module,
and its submodules, implements these solutions in a generic way.
See the module documentation for details and how to extend for your own entities
and cases.


INTEGRATION WITH OTHER MODULES
------------------------------

 * Events:
   * The CookieProGetDomainScript event is dispatched before generation of the
     CookiePro snippet, allowing conditional override of the script ID.

 * Library handling. CookieproJsCollectionRenderer will process any Javascript
    file that is 'tagged' with attribute 'cookie_category', and wrap it in a
    way that CookiePro will load them the corresponding consent is given.
    More info on [Client-Side Cookie Management](https://community.cookiepro.com/s/article/UUID-730ad441-6c4d-7877-7f85-36f1e801e8ca?topicId=0TO1Q000000ssKJWAY#idm2048)

    This approach allows for 2 ways to 'tag' module scripts for processing:

   * Using libraries.yml: see [example libraries.yml](./examples/mymodule.libraries.yml).
   * Using hook_library_info_alter(): see [example module hooks](./examples/mymodule.module).


NOT SUPPORTED OR TESTED
-----------------------

 * Custom cookie categories
 * Multiple cookie categories on an iframe or script.
 * Cross-domain consent


TROUBLESHOOTING
---------------

 * For CookiePro script related problems, see the [CookiePro knowledgebase and
    their support](https://community.cookiepro.com).
 * For module issues, see the
  [module issue queue](https://www.drupal.org/project/issues/cookiepro_plus).


MAINTAINERS
-----------

 * Andreas De Rijcke (andreasderijcke) - https://www.drupal.org/user/3260992

This project has been sponsored by:

 * CALIBRATE: We are a full-service Drupal service provider based out of Europe.
   We help our clients with digital strategic planning, UX and UI design and
   testing, development, and digital marketing services. As a data driven
   strategic partner, we use facts, research and KPI's to achieve better results.
   Want to learn more about Calibrate? Visit https://www.calibrate.be.
