<?php

namespace Drupal\cookiepro_plus\Event;

use Drupal\Core\Config\Config;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Class CookieProGetDomainScript.
 *
 * Defines the CookiePro Get Domain Script event, which allows other modules
 * to override the active CookiePro Domain Script to be used.
 */
class CookieProGetDomainScript extends Event {

  const EVENT_NAME = 'cookiepro.get_domain_script';

  /**
   * The corresponding config.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * The domain script.
   *
   * @var string
   */
  protected $domainScript;

  /**
   * CookieProGetDomainScript constructor.
   *
   * @param string $domain_script
   *   The domain script.
   * @param \Drupal\Core\Config\Config $config
   *   The corresponding config.
   */
  public function __construct(string $domain_script, Config $config) {
    $this->domainScript = $domain_script;
    $this->config = $config;
  }

  /**
   * Get the corresponding config.
   *
   * @return \Drupal\Core\Config\Config
   *   The config.
   */
  public function getConfig(): Config {
    return $this->config;
  }

  /**
   * Get the domain script.
   *
   * @return string
   *   The domain script.
   */
  public function getDomainScript(): string {
    return $this->domainScript;
  }

  /**
   * Set the domain script.
   *
   * @param string $domain_script
   *   The domain script.
   *
   * @return \Drupal\cookiepro_plus\Event\CookieProGetDomainScript
   *   The updated event.
   */
  public function setDomainScript(string $domain_script): CookieProGetDomainScript {
    $this->domainScript = $domain_script;
    return $this;
  }

}
