<?php

namespace Drupal\cookiepro_plus\PageCache\RequestPolicy;

use Drupal\cookiepro_plus\CookieProInterface;
use Drupal\Core\PageCache\RequestPolicyInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class CookieProDenyCacheForWhitelistedIp.
 *
 * A policy allowing cache bypass for CookiePro whitelisted IP's.
 */
class CookieProDenyCacheForWhitelistedIp implements RequestPolicyInterface {

  /**
   * The CookiePro service.
   *
   * @var \Drupal\cookiepro_plus\CookieProInterface
   */
  protected $cookiePro;

  /**
   * IsWhitelistedIp constructor.
   *
   * @param \Drupal\cookiepro_plus\CookieProInterface $cookiepro
   *   The CookiePro service.
   */
  public function __construct(CookieProInterface $cookiepro) {
    $this->cookiePro = $cookiepro;
  }

  /**
   * {@inheritdoc}
   */
  public function check(Request $request): ?string {

    if (!$this->cookiePro->isPaused() && $this->cookiePro->isWhitelistedIp($request)) {
      return static::DENY;
    }

    // No opinion.
    return NULL;
  }

}
